/* Communication: Main Interface
   Copyright (c) 2010 Networked Systems Group, University of Kaiserslautern

This file is part of the Imote2 Bootloader

The Bootloader is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

The Bootloader is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef COMMUNICATION_H
#define COMMUNICATION_H

#include <inttypes.h>
#include "../config.h"

/** \addtogroup communication
 * @{
 */

/** \file communication.h
 * \brief communication subsystem
 */

/** \brief Packet structure for both directions */
struct PacketHeader {
	/** \brief length of packet */
	uint16_t length;
	/** \brief command */
	uint8_t cmd;
	
	uint8_t flagCompressed : 1;
	uint8_t reservedFlags : 7;
	
	uint8_t data[0];
} __attribute__((packed));

struct PacketAddress {
	/** \brief address to be flashed */
	uint32_t address;
	/** \brief length to be flashed */
	uint32_t length;
} __attribute__((packed));

void communicationProcessPacket(const struct PacketHeader * pkt,
	const void * payload, uint32_t payloadLen);

/** @} */

#endif

