/* Communication: Buffering
   Copyright (c) 2010 Networked Systems Group, University of Kaiserslautern

This file is part of the Imote2 Bootloader

The Bootloader is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

The Bootloader is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef COMMUNICATION_BUFFER_INTERNAL_H
#define COMMUNICATION_BUFFER_INTERNAL_H

#include <inttypes.h>
#include "communication.h"
#include "../config.h"

/** \cond INTERNAL */

/** \addtogroup communicationbuf
 * @{
 */

/** \file communication_buffer_internal.h
 * \brief internal structures for communication buffer subsystem
 */
 
/** \brief Packet Buffer */
struct Buffer {
	/** \brief length of buffer */
	uint16_t length;
	/** \brief position inside buffer */
	uint16_t pos;
	union {
		/** \brief raw data */
		uint8_t data[COMM_PKT_SIZE];
		/** \brief packet */
		struct PacketHeader pkt;
	};
};

/** \brief Communication System */
struct CommunicationSystem {
	/** \brief called when communcation system is started */
	void (*start)(struct CommunicationSystem*);
	/** \brief called when communication system is stopped */
	void (*stop)(struct CommunicationSystem*);
	
	/** \brief called when a packet should be sent by the communication driver */
	void (*send)(struct CommunicationSystem*,const void*,uint32_t);
};

void communicationReset();
void communicationConfigured();

void communicationSendPacket(const struct PacketHeader * pkt);
void communicationReceive(const void * data, uint32_t length);

/** @} */

/** \endcond */

#endif

