/* DMA Controller
   Copyright (c) 2010 Networked Systems Group, University of Kaiserslautern

This file is part of the Imote2 Bootloader

The Bootloader is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

The Bootloader is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef DMA_H
#define DMA_H

#include <inttypes.h>
#include "driver.h"

/** \addtogroup dma
 * @{
 */

/** \file dma.h
 * \brief Routines for the Direct Memory Access Controller
 */

extern struct Driver dmaDriver;

/** \brief dma descriptor */
struct DmaDescriptor {
	/** \brief next descriptor in chain and stop bit */
	struct DmaDescriptor * ddadr;
	/** \brief source address */
	const void * dsadr;
	/** \brief destination address */
	void * dtadr;
	/** \brief dma command */
	uint32_t dcmd;
} __attribute__((packed));

bool dmaGetChannel(uint8_t priority, uint8_t * channel, uint32_t drcm,
	void (*cbDmaInterrupt)(uint8_t channel, uint32_t remainingLength,
		void * data), void * data);
void dmaReleaseChannel(uint8_t channel);

void dmaSetupHWToMem(uint8_t channel, const void * sourceReg, void * destMem,
	uint8_t size, uint8_t width, uint32_t len);
void dmaSetupMemToHW(uint8_t channel, const void * sourceMem, void * destReg,
	uint8_t size, uint8_t width, uint32_t len);

struct DmaDescriptor * dmaAllocateDescriptor();

void dmaSetupDescMemToHW(struct DmaDescriptor * desc, bool stop,
	const void * sourceMem, void * destReg, uint8_t size, uint8_t width,
	uint32_t len);
void dmaSetupDescHWToMem(struct DmaDescriptor * desc, bool stop,
	const void * sourceReg, void * destMem, uint8_t size, uint8_t width,
	uint32_t len);
void dmaSetupDescMemToMem(struct DmaDescriptor * desc, bool stop,
	const void * sourceMem, void * destMem, uint8_t size, uint32_t len);

void dmaSetupDescSetNextDesc(struct DmaDescriptor * desc,
	const struct DmaDescriptor * next);

void dmaSetupDescStart(uint8_t channel, const struct DmaDescriptor * desc);

void dmaFreeDescriptorChain(struct DmaDescriptor * desc);

void dmaKillChannel(uint8_t channel);

void dmaRemapChannel(uint8_t channel);

void dmaStopChannel(uint8_t channel);

void dmaInterrupt();

/** @} */

#endif

