/* Timer Driver
   Copyright (c) 2010 Networked Systems Group, University of Kaiserslautern

This file is part of the Imote2 Bootloader

The Bootloader is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

The Bootloader is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef TIMER_H
#define TIMER_H

#include <inttypes.h>
#include <os_arm_bare_registers_def.h>
#include "driver.h"

/** \addtogroup timer
 * @{
 */

/** \file timer.h
 * \brief OS Timer 4-11 routines
 */

extern struct Driver timerDriver;

void timerStopAll();

void timerSet(uint8_t timerId, uint8_t resolution, bool compareBase,
	bool periodic, bool reset);

void timerStart(uint8_t timerId, uint32_t start);

void timerStop(uint8_t timerId);

void timerWait(uint8_t timerId, uint8_t resolution, bool compareBase,
	bool periodic, bool reset,
	uint32_t duration, void(*cbTimer)(uint8_t timerId));

/** read timer value
 * \param timerId timer Id (4-11)
 * \return timer value */
static inline uint32_t timerGet(uint8_t timerId) {
	return OSCR4_11(timerId);
}

void timerInterrupt();

/** @} */

#endif

