/* USB Driver: Macros for debugging
   Copyright (c) 2010 Networked Systems Group, University of Kaiserslautern

This file is part of the Imote2 Bootloader

The driver contains ideas taken from the linux gadget device driver,
licenced under the GPL.

The Bootloader is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

The Bootloader is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef USB_DEBUG_H
#define USB_DEBUG_H

#include "../debug.h"

#if DEBUG_USB_LEVEL >= 1
#define usbErr(_str, _args...) \
	debugf("UDC: " _str, ##_args)
#else
#define usbErr(_str, _args...) do {} while(0)
#endif

#if DEBUG_USB_LEVEL >= 2
#define usbInfo(_str, _args...) \
	debugf("UDC: " _str, ##_args)
#else
#define usbInfo(_str, _args...) do {} while(0)
#endif

#if DEBUG_USB_LEVEL >= 3
#define usbDebug(_str, _args...) \
	debugf("UDC: " _str, ##_args)
#else
#define usbDebug(_str, _args...) do {} while(0)
#endif


#if DEBUG_USB_CP_LEVEL >= 1
#define usbCPErr(_str, _args...) \
	debugf("UDC CP: " _str, ##_args)
#else
#define usbCPErr(_str, _args...) do {} while(0)
#endif

#if DEBUG_USB_CP_LEVEL >= 2
#define usbCPInfo(_str, _args...) \
	debugf("UDC CP: " _str, ##_args)
#else
#define usbCPInfo(_str, _args...) do {} while(0)
#endif

#if DEBUG_USB_CP_LEVEL >= 3
#define usbCPDebug(_str, _args...) \
	debugf("UDC CP: " _str, ##_args)
#else
#define usbCPDebug(_str, _args...) do {} while(0)
#endif


#if DEBUG_USB_EP_LEVEL >= 1
#define usbEPErr(_ep, _str, _args...) \
	debugf("UDC EP%d: " _str, (_ep)->udcEndpoint, ##_args)
#else
#define usbEPErr(_ep, _str, _args...) do {} while(0)
#endif

#if DEBUG_USB_EP_LEVEL >= 2
#define usbEPInfo(_ep, _str, _args...) \
	debugf("UDC EP%d: " _str, (_ep)->udcEndpoint, ##_args)
#else
#define usbEPInfo(_ep, _str, _args...) do {} while(0)
#endif

#if DEBUG_USB_EP_LEVEL >= 3
#define usbEPDebug(_ep, _str, _args...) \
	debugf("UDC EP%d: " _str, (_ep)->udcEndpoint, ##_args)
#else
#define usbEPDebug(_ep, _str, _args...) do {} while(0)
#endif

#endif

